==> cook_2.5.orig.tar.gz: cook-2.5.orig/test/01/t0112a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the graph functionality
#
work=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
SHELL=/bin/sh
export SHELL

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the graph functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the graph functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

#
# test the graph functionality
#
cat > Howto.cook << 'fubar'
%.c %.h: %.y
{
	/*
	 * Should not be run in this test, but it exersizes a variety of
	 * backtracking in the build phase.
	 */
	yacc -d %.y;
	mv y.tab.c %.c;
	mv y.tab.h %.h;
}

%.o: %.c
{
	echo [need] > [target];
}

prog: a.o b.o c.o
{
	echo [need] > [target];
}

a.o: a.h b.h c.h;
b.o: b.h c.h;
c.o: c.h;
fubar
if test $? -ne 0 ; then no_result; fi

# create all of the leaf files
for f in b.o a.c b.c c.c a.h b.h c.h; do date > $f; sleep 1; done
if test $? -ne 0 ; then no_result; fi

# create ONE of the intermediate files
sleep 2
cat > test.ok << 'fubar'
this is the unique bit
fubar
if test $? -ne 0 ; then no_result; fi
cp test.ok b.o

#
# Now actually run the build and make sure it does the right things.
#
$bin/cook -nl > test.log 2>&1
if test $? -ne 0 ; then cat test.log; fail; fi

#
# it should create all of the derived files,
# except b.o which already existed.
#
test -f a.o || fail
cmp test.ok b.o || fail
test -f c.o || fail
test -f prog || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass

==> cook_2.19.orig.tar.gz: cook-2.19.orig/test/01/t0112a.sh <==
#!/bin/sh
#
#	cook - file construction tool
#	Copyright (C) 1997, 1998 Peter Miller;
#	All rights reserved.
#
#	This program is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation; either version 2 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
#
# MANIFEST: Test the graph functionality
#
work=${COOK_TMP:-/tmp}/$$
PAGER=cat
export PAGER
umask 022
unset COOK
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
SHELL=/bin/sh
export SHELL

bin="$here/${1-.}/bin"

pass()
{
	set +x
	cd $here
	rm -rf $work
	exit 0
}
fail()
{
	set +x
	echo 'FAILED test of the graph functionality' 1>&2
	cd $here
	rm -rf $work
	exit 1
}
no_result()
{
	set +x
	echo 'NO RESULT for test of the graph functionality' 1>&2
	cd $here
	rm -rf $work
	exit 2
}
trap \"no_result\" 1 2 3 15

mkdir $work $work/lib
if test $? -ne 0 ; then no_result; fi
cd $work
if test $? -ne 0 ; then no_result; fi

#
# Use the default error messages.  There is no other way to get
# predictable test behaviour on the unknown systems we will be tested on.
#
COOK_MESSAGE_LIBRARY=$work/no-such-dir
export COOK_MESSAGE_LIBRARY
unset LANG

#
# test the graph functionality
#
cat > Howto.cook << 'fubar'
%.c %.h: %.y
{
	/*
	 * Should not be run in this test, but it exersizes a variety of
	 * backtracking in the build phase.
	 */
	yacc -d %.y;
	mv y.tab.c %.c;
	mv y.tab.h %.h;
}

%.o: %.c
{
	echo [need] > [target];
}

prog: a.o b.o c.o
{
	echo [need] > [target];
}

a.o: a.h b.h c.h;
b.o: b.h c.h;
c.o: c.h;
fubar
if test $? -ne 0 ; then no_result; fi

# create all of the leaf files
for f in b.o a.c b.c c.c a.h b.h c.h; do date > $f; sleep 1; done
if test $? -ne 0 ; then no_result; fi

# create ONE of the intermediate files
sleep 2
cat > test.ok << 'fubar'
this is the unique bit
fubar
if test $? -ne 0 ; then no_result; fi
cp test.ok b.o

#
# Now actually run the build and make sure it does the right things.
#
$bin/cook -nl > test.log 2>&1
if test $? -ne 0 ; then cat test.log; fail; fi

#
# it should create all of the derived files,
# except b.o which already existed.
#
test -f a.o || fail
diff test.ok b.o || fail
test -f c.o || fail
test -f prog || fail

#
# Only definite negatives are possible.
# The functionality exercised by this test appears to work,
# no other guarantees are made.
#
pass
